LowRankRepresentation
=====================

.. currentmodule:: pykeen.nn.representation

.. autoclass:: LowRankRepresentation
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~LowRankRepresentation.num_bases

   .. rubric:: Methods Summary

   .. autosummary::

      ~LowRankRepresentation.approximate
      ~LowRankRepresentation.reset_parameters

   .. rubric:: Attributes Documentation

   .. autoattribute:: num_bases

   .. rubric:: Methods Documentation

   .. automethod:: approximate
   .. automethod:: reset_parameters
